# Generated by Django 2.1.14 on 2019-12-04 10:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0031_merge_20191202_1119'),
        ('djautotask', '0032_auto_20191129_1501'),
    ]

    operations = [
    ]
