# Generated by Django 2.1.14 on 2019-11-25 09:39

from django.db import migrations


class Migration(migrations.Migration):
    atomic = False
    dependencies = [
        ('djautotask', '0024_auto_20191122_1516'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='TicketPriority',
            new_name='Priority',
        ),
    ]
