# Generated by Django 2.1.11 on 2019-09-20 12:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0004_auto_20190913_1425'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='ticketstatus',
            name='value',
        ),
    ]
